==> kubernetes-client-4.11.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/policy/v1beta1/PodDisruptionBudgetOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.policy.v1beta1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.policy.DoneablePodDisruptionBudget;
import io.fabric8.kubernetes.api.model.policy.PodDisruptionBudget;
import io.fabric8.kubernetes.api.model.policy.PodDisruptionBudgetList;
import io.fabric8.kubernetes.api.model.policy.DoneablePodDisruptionBudget;

import java.util.Map;
import java.util.TreeMap;


public class PodDisruptionBudgetOperationsImpl extends HasMetadataOperation<PodDisruptionBudget, PodDisruptionBudgetList, DoneablePodDisruptionBudget, Resource<PodDisruptionBudget, DoneablePodDisruptionBudget>> {

  public PodDisruptionBudgetOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public PodDisruptionBudgetOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public PodDisruptionBudgetOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("policy")
    .withApiGroupVersion("v1beta1")
    .withPlural("poddisruptionbudgets"));
    this.type = PodDisruptionBudget.class;
    this.listType = PodDisruptionBudgetList.class;
    this.doneableType = DoneablePodDisruptionBudget.class;
  }

  public PodDisruptionBudgetOperationsImpl newInstance(OperationContext context) {
    return new PodDisruptionBudgetOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.3.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/policy/v1beta1/PodDisruptionBudgetOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.policy.PodDisruptionBudget;
import io.fabric8.kubernetes.api.model.policy.PodDisruptionBudgetBuilder;
import io.fabric8.kubernetes.api.model.policy.PodDisruptionBudgetList;

import java.util.Map;
import java.util.TreeMap;


public class PodDisruptionBudgetOperationsImpl extends HasMetadataOperation<PodDisruptionBudget, PodDisruptionBudgetList, Resource<PodDisruptionBudget>> {

  public PodDisruptionBudgetOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public PodDisruptionBudgetOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public PodDisruptionBudgetOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("policy")
    .withApiGroupVersion("v1beta1")
    .withPlural("poddisruptionbudgets"));
    this.type = PodDisruptionBudget.class;
    this.listType = PodDisruptionBudgetList.class;
  }

  public PodDisruptionBudgetOperationsImpl newInstance(OperationContext context) {
    return new PodDisruptionBudgetOperationsImpl(context);
  }

  @Override
  public PodDisruptionBudget edit(Visitor... visitors) {
    return patch(new PodDisruptionBudgetBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
